GitHub API client module for repository exploration.
This module provides functions for interacting with the GitHub API to:
- List directory contents
- Read file contents
- Search code
- List and switch branches
- Search for repositories
- Search and read issues
- Search and read pull requests
All API calls are made through the octocrab client with optional authentication.
Re-exports
pub use client::create_client;pub use client::get_repo_info;pub use client::list_branches;pub use issues::IssueSearchFilters;pub use pulls::PRSearchFilters;
Modules
- client
- GitHub API client for repository content operations.
- commits
- GitHub Commits API client functions.
- issues
- GitHub Issues API client functions.
- pulls
- GitHub Pull Requests API client functions.
- releases
- GitHub Releases API client functions.
- search
- GitHub repository search functionality.
- stats
- GitHub Repository Stats API client functions.
Structs
- Rate
Limit Info - Rate limit information from GitHub API.
Functions
- is_
rate_ limited - Check if we’re close to rate limit (less than 10% remaining).
- retry_
with_ backoff - Retry a GitHub API call with exponential backoff.